==> librepcb-0.1.7-source.zip: librepcb-0.1.7/libs/librepcb/editor/project/cmd/cmdflipselectedboarditems.h <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBREPCB_EDITOR_CMDFLIPSELECTEDBOARDITEMS_H
#define LIBREPCB_EDITOR_CMDFLIPSELECTEDBOARDITEMS_H

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "../../undocommandgroup.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace / Forward Declarations
 ******************************************************************************/
namespace librepcb {

class BI_Device;
class Board;

namespace editor {

/*******************************************************************************
 *  Class CmdFlipSelectedBoardItems
 ******************************************************************************/

/**
 * @brief The CmdFlipSelectedBoardItems class
 */
class CmdFlipSelectedBoardItems final : public UndoCommandGroup {
public:
  // Constructors / Destructor
  CmdFlipSelectedBoardItems(Board& board, Qt::Orientation orientation) noexcept;
  ~CmdFlipSelectedBoardItems() noexcept;

private:
  // Private Methods

  /// @copydoc ::librepcb::editor::UndoCommand::performExecute()
  bool performExecute() override;

  // Private Member Variables

  // Attributes from the constructor
  Board& mBoard;
  Qt::Orientation mOrientation;
};

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace editor
}  // namespace librepcb

#endif

==> librepcb-1.3.0-source.zip: librepcb-1.3.0/libs/librepcb/editor/project/cmd/cmdflipselectedboarditems.h <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBREPCB_EDITOR_CMDFLIPSELECTEDBOARDITEMS_H
#define LIBREPCB_EDITOR_CMDFLIPSELECTEDBOARDITEMS_H

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "../../undocommandgroup.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace / Forward Declarations
 ******************************************************************************/
namespace librepcb {

class BI_Device;

namespace editor {

class BoardGraphicsScene;

/*******************************************************************************
 *  Class CmdFlipSelectedBoardItems
 ******************************************************************************/

/**
 * @brief The CmdFlipSelectedBoardItems class
 */
class CmdFlipSelectedBoardItems final : public UndoCommandGroup {
public:
  // Constructors / Destructor
  CmdFlipSelectedBoardItems(BoardGraphicsScene& scene,
                            Qt::Orientation orientation,
                            bool includeLockedItems) noexcept;
  ~CmdFlipSelectedBoardItems() noexcept;

private:
  // Private Methods

  /// @copydoc ::librepcb::editor::UndoCommand::performExecute()
  bool performExecute() override;

  // Private Member Variables

  // Attributes from the constructor
  BoardGraphicsScene& mScene;
  Qt::Orientation mOrientation;
  bool mIncludeLockedItems;
};

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace editor
}  // namespace librepcb

#endif
